@@ -25,7 +25,7 @@ class display_grand_total(TemplateView):
                 for client_stat_entry in client_stat_entries:
                     stat_type = client_stat_entry.type.name
                     stat_value = client_stat_entry.value
-                    if stat_type in client_data:
+                    if stat_type in global_stats:
                         global_stats[stat_type] += stat_value
                     else:
                         global_stats[stat_type] = stat_value
